@@ -5,7 +5,7 @@ use vars qw($VERSION);
 
 use Alzabo;
 
-$VERSION = sprintf '%2d.%02d', q$Revision: 1.21 $ =~ /(\d+)\.(\d+)/;
+$VERSION = sprintf '%2d.%02d', q$Revision: 1.22 $ =~ /(\d+)\.(\d+)/;
 
 1;
 
@@ -45,6 +45,14 @@ sub column_pairs
 	     0..$#{ $self->{columns_from} } );
 }
 
+sub column_pair_names
+{
+    my $self = shift;
+
+    return ( map { [ $self->{columns_from}[$_]->name => $self->{columns_to}[$_]->name ] }
+	     0..$#{ $self->{columns_from} } );
+}
+
 sub cardinality
 {
     my $self = shift;
