@@ -8,13 +8,12 @@ use Alzabo::Runtime;
 use Params::Validate qw( :all );
 Params::Validate::validation_options( on_fail => sub { Alzabo::Exception::Params->throw( error => join '', @_ ) } );
 
+use Tie::IxHash;
 use Time::HiRes qw(time);
 
 use base qw(Alzabo::Table);
 
-$VERSION = sprintf '%2d.%02d', q$Revision: 1.69 $ =~ /(\d+)\.(\d+)/;
-
-1;
+$VERSION = sprintf '%2d.%02d', q$Revision: 1.73 $ =~ /(\d+)\.(\d+)/;
 
 sub insert
 {
@@ -233,7 +232,7 @@ sub _make_sql
     my $self = shift;
 
     my $sql = ( $self->schema->sqlmaker->
-		select( $self->primary_key, $self->columns( $self->prefetch ) )->
+		select( $self->primary_key, $self->prefetch ? $self->columns( $self->prefetch ) : () )->
 		from( $self ) );
 
     return $sql;
@@ -380,7 +379,7 @@ sub _canonize_prefetch
 	    unless $self->{columns}->EXISTS( $c->name );
     }
 
-    return [ map {$_->name} grep { ! $_->is_primary_key($_) } @_ ]
+    return [ map { $_->name } grep { ! $_->is_primary_key } @_ ];
 }
 
 sub prefetch
@@ -415,6 +414,68 @@ sub group_by_column
     return exists $self->{groups}{$col} ? @{ $self->{groups}{$col} } : $col;
 }
 
+my $alias_num = '000000000';
+sub alias
+{
+    my $self = shift;
+
+    my $clone;
+    %$clone = %$self;
+
+    bless $clone, ref $self;
+
+    $clone->{alias_name} = $self->name . ++$alias_num;
+    $clone->{real_table} = $self;
+
+    $clone->{columns} = Tie::IxHash->new( map { $_->name => $_ } $self->columns );
+
+    return $clone;
+}
+
+#
+# Since its unlikely that a user will end up needing clones of more
+# than 1-2 columns each time an alias is used, we only make copies as
+# needed.
+#
+sub column
+{
+    my $self = shift;
+
+    # I'm an alias, make an alias column
+    if ( $self->{alias_name} )
+    {
+	my $name = shift;
+	my $col = $self->SUPER::column($name);
+
+	# not previously cloned
+	unless ( $col->table eq $self )
+	{
+	    # replace our copy of this column with a clone
+	    $col = $col->alias_clone( table => $self );
+	    my $index = $self->{columns}->Indices($name);
+	    $self->{columns}->Replace( $index, $col, $name );
+	}
+
+	return $col;
+    }
+    else
+    {
+	return $self->SUPER::column(@_);
+    }
+}
+
+sub alias_name
+{
+    return $_[0]->{alias_name} || $_[0]->name;
+}
+
+sub real_table
+{
+    return $_[0]->{real_table} || $_[0];
+}
+
+1;
+
 __END__
 
 =head1 NAME
@@ -619,11 +680,6 @@ parameter.
 This parameter can take either a single column object or an array of
 column objects.
 
-Some RDBMS backends may also allow you to pass sorting identifiers
-just as with an order by clause.  However, for portability it is
-recommended that you simply use an order by clause in addition to your
-group by clause.
-
 =item * limit => $limit or [ $limit, $offset ]
 
 For databases that support LIMIT clauses, this incorporates such a
@@ -745,7 +801,7 @@ object.
 
 A scalar indicating how many rows the table has.
 
-=head2 function/select
+=head2 function and select
 
 These two methods differ only in their return values.
 
@@ -796,6 +852,24 @@ This method always returns a new
 L<C<Alzabo::DriverStatement>|Alzabo::Driver/Alzabo::DriverStatement>
 object containing the results of the query.
 
+=head2 alias
+
+=head3 Returns
+
+An object which can be used in joins to allow a particular table to be
+involved in the join under multiple aliases.  This allows for
+self-joins as well as more complex joins involving multiple aliases of
+a given table.
+
+The object returned by this method is more or less identical to a
+table object in terms of the methods it supports.  This includes
+methods that were generated by Alzabo::MethodMaker.
+
+However, B<this object should not be used outside the context of a
+join query> because the results will be unpredictable.  In addition,
+B<the column objects that the alias returns should also not be used
+outside of the context of a join>.
+
 =for pod_merge schema
 
 =for pod_merge name
