@@ -2,7 +2,7 @@ sub mysql_clean_schema
 {
     my %p = @_;
 
-    warn "Removing MySQL database $p{schema_name}\n";
+    warn "\n# Removing MySQL database $p{schema_name}\n";
 
     my $s = Alzabo::Create::Schema->new( name => $p{schema_name},
 					 rdbms => 'MySQL' );
@@ -18,7 +18,7 @@ sub pg_clean_schema
     my $s = Alzabo::Create::Schema->new( name => $p{schema_name},
 					 rdbms => 'PostgreSQL' );
 
-    warn "Removing PostgreSQL database $p{schema_name}\n";
+    warn "\n# Removing PostgreSQL database $p{schema_name}\n";
 
     delete $p{rdbms};
     $s->drop(%p);
